@@ -25,8 +25,6 @@
 #include <sys/types.h>
 #include <gio/gio.h>
 
-#include <libanjuta/anjuta-preferences.h>
-
 G_BEGIN_DECLS
 
 gboolean anjuta_util_copy_file (const gchar * src, const gchar * dest, gboolean show_error);
@@ -38,8 +36,6 @@ void anjuta_util_color_from_string (const gchar * val, guint16 * r,
 
 gchar* anjuta_util_string_from_color (guint16 r, guint16 g, guint16 b);
 
-GdkColor* anjuta_util_convert_color(AnjutaPreferences* prefs, const gchar* pref_name);
-
 GtkWidget* anjuta_util_button_new_with_stock_image (const gchar* text,
 													const gchar* stock_id);
 
@@ -105,8 +101,10 @@ GList * anjuta_util_update_string_list (GList *p_list, const gchar *p_str,
 										gint length);
 
 gboolean anjuta_util_create_dir (const gchar * d);
-char * anjuta_util_user_shell (void);
+gchar * anjuta_util_user_shell (void);
+gchar ** anjuta_util_user_terminal (void);
 pid_t anjuta_util_execute_shell (const gchar *dir, const gchar *command);
+pid_t anjuta_util_execute_terminal_shell (const gchar *dir, const gchar *command);
 
 gchar* anjuta_util_escape_quotes(const gchar* str);
 
@@ -134,6 +132,16 @@ gchar* anjuta_util_get_user_data_file_path (const gchar* path, ...);
 gchar* anjuta_util_get_user_cache_file_path (const gchar* path, ...);
 gchar* anjuta_util_get_user_config_file_path (const gchar* path, ...);
 
+/* Function for converting GFile objects to string paths 
+ * Free the returned list with anjuta_util_glist_strings_free. */
+GList *anjuta_util_convert_gfile_list_to_path_list (GList *list);
+GList *anjuta_util_convert_gfile_list_to_relative_path_list (GList *list, 
+															 const gchar *parent);
+
+/* Helper functions to load a GtkBuilder file and get widgets */
+GtkBuilder *anjuta_util_builder_new (const gchar *filename, GError **error);
+gboolean anjuta_util_builder_get_objects (GtkBuilder *builder, const gchar *first_widget,...);
+
 /* Temporarily copied here */
 
 #define ANJUTA_TYPE_BEGIN(class_name, prefix, parent_type) \
