@@ -5,10 +5,7 @@
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/anjuta-ui.h>
 
-#include "indent-util.h"
-#include "indent-dialog.h"
-
-extern GType docman_plugin_get_type (AnjutaGluePlugin *plugin);
+extern GType docman_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_DOCMAN         (docman_plugin_get_type (NULL))
 #define ANJUTA_PLUGIN_DOCMAN(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_DOCMAN, DocmanPlugin))
 #define ANJUTA_PLUGIN_DOCMAN_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_DOCMAN, DocmanPluginClass))
@@ -27,11 +24,14 @@ struct _DocmanPlugin{
 	gint uiid;
 	GList *action_groups;
 	
+	/* project_root_uri watch*/
+	gint project_watch_id;
+	gchar* project_name;
+  gchar* project_path;
+	
 	/*! state flag for Ctrl-TAB */
 	gboolean g_tabbing;
 	
-	IndentData *idt;
-	
 	/* Autosave timer ID */
 	gint autosave_id;
 	gboolean autosave_on;
@@ -43,6 +43,15 @@ struct _DocmanPlugin{
 	
 	/* Support plugins */
 	GList *support_plugins;
+  
+  /* SearchBox */
+  GtkWidget* search_box;
+	
+	/* Base box of the widget */
+	GtkWidget* vbox;
+	
+	/* Bookmarks */
+	GObject* bookmarks;
 };
 
 struct _DocmanPluginClass{
