@@ -38,7 +38,6 @@
 #include <signal.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <libgnome/gnome-macros.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 #include <libanjuta/gbf-project.h>
@@ -3237,8 +3236,13 @@ impl_add_source (GbfProject  *_project,
 	/* if the uri is relative, resolve it against the target's
 	 * group directory; we need to compute the group's uri
 	 * first */
-	group_uri = uri_normalize (g_path_skip_root (GBF_MKFILE_NODE (g_node->parent)->id),
-				   project->project_root_uri);
+        if (g_path_is_absolute (GBF_MKFILE_NODE (g_node->parent)->id)) {
+          group_uri = uri_normalize (g_path_skip_root (GBF_MKFILE_NODE (g_node->parent)->id),
+                                     project->project_root_uri);
+        } else {
+          group_uri = uri_normalize (GBF_MKFILE_NODE (g_node->parent)->id,
+                                                   project->project_root_uri);
+        }
 	full_uri = uri_normalize (uri, group_uri);
 	g_free (group_uri);
 	
@@ -3488,8 +3492,8 @@ gbf_mkfile_project_dispose (GObject *object)
 	g_free (project->configure_command);
 	g_free (project->autogen_command);
 	g_free (project->install_prefix);
-	
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
+
+	G_OBJECT_CLASS (parent_class)->dispose (object);	
 }
 
 static void
