@@ -48,8 +48,10 @@ typedef struct _SymbolDBPluginClass SymbolDBPluginClass;
 #include "symbol-db-system.h"
 #include "symbol-db-prefs.h"
 
-/* a sort of 'default' value for ctags executable. User must have it installed */
-#define CTAGS_PATH			"/usr/bin/ctags"
+/* default value for ctags executable. User must have it installed. This is a 
+ * personalized version of ctags for Anjuta.
+ */
+#define CTAGS_PATH	PACKAGE_BIN_DIR"/anjuta-tags"
 
 struct _SymbolDBPlugin {
 	AnjutaPlugin parent;
@@ -70,6 +72,12 @@ struct _SymbolDBPlugin {
 	GTimer *update_timer;
 	GPtrArray *buffer_update_files;
 	GPtrArray *buffer_update_ids;
+	gboolean buffer_update_semaphore;		/* it monitors the update status of the
+	 										 * buffer _and_ the editor switching.
+	 										 * A new page cannot be updated with the
+	 										 * new view-locals symbols if a scanning
+	 										 * is in progress 
+	 										 */
 	guint editor_watch_id;
 	gchar *project_root_uri;
 	gchar *project_root_dir;
@@ -88,9 +96,15 @@ struct _SymbolDBPlugin {
 	SymbolDBPrefs *sdbp;
 	
 	GtkWidget *dbv_main;					/* symbol main window [gtk_box] */
-	GtkWidget *dbv_notebook;          		/* main notebook */	
+	GtkWidget *dbv_notebook;          		/* main notebook */
+	GtkWidget *dbv_hbox;					/* hbox for notebook buttons */
 	GtkWidget *scrolled_global; 			/* symbol view scrolledwindow for global
 										   	symbols */
+
+	GtkWidget *local_button;
+	GtkWidget *global_button;
+	GtkWidget *search_button;
+	
 	GtkWidget *scrolled_locals;
 	GtkWidget *scrolled_search;
 	GtkWidget *progress_bar_project;		/* symbol db progress bar - project */
@@ -122,7 +136,9 @@ struct _SymbolDBPlugin {
 	gchar *current_scanned_package;
 	GList *session_packages;
 	
-	GTree *proc_id_tree;
+	GTree *proc_id_tree;				/* the scan processes'll receive an id from 
+	 									 * the symbol engine when scan-end happens. 
+	 									 * Track them here */
 	
 	gboolean is_project_importing;		/* refreshes or resumes after abort */
 	gboolean is_project_updating;		/* makes up to date symbols of the project's files */
