@@ -33,7 +33,7 @@
 
 /*---------------------------------------------------------------------------*/
 
-/* Widget and signal name found in glade file
+/* Widget and signal name found in gtk builder file
  *---------------------------------------------------------------------------*/
 
 #define TOOL_LIST "list_tools"
@@ -43,12 +43,13 @@
 #define TOOL_UP_BUTTON "up_bt"
 #define TOOL_DOWN_BUTTON "down_bt"
 
-#define TOOL_ADD_SIGNAL "on_tool_add"
-#define TOOL_ACTIVATED_SIGNAL "on_tool_activated"
-#define TOOL_EDIT_SIGNAL "on_tool_edit"
-#define TOOL_DELETE_SIGNAL "on_tool_delete"
-#define TOOL_UP_SIGNAL "on_tool_up"
-#define TOOL_DOWN_SIGNAL "on_tool_down"
+/* Gtk builder callbacks */
+void atp_on_tool_add (GtkButton *button, gpointer user_data);
+void atp_on_tool_activated (GtkTreeView  *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer user_data);
+void atp_on_tool_edit (GtkButton *button, gpointer user_data);
+void atp_on_tool_delete (GtkButton *button, gpointer user_data);
+void atp_on_tool_up (GtkButton *button, gpointer user_data);
+void atp_on_tool_down (GtkButton *button, gpointer user_data);
 
 /* column of the list view */
 enum {
@@ -123,8 +124,8 @@ get_current_writable_tool (ATPToolDialog *this)
 /* Call backs
  *---------------------------------------------------------------------------*/
 
-static void
-on_tool_add (GtkButton *button, gpointer user_data)
+void
+atp_on_tool_add (GtkButton *button, gpointer user_data)
 {
 	ATPToolDialog *this = (ATPToolDialog *)user_data;
 	ATPUserTool *tool;
@@ -147,8 +148,8 @@ on_tool_add (GtkButton *button, gpointer user_data)
 	atp_tool_editor_show (ted);
 }
 
-static void
-on_tool_edit (GtkButton *button, gpointer user_data)
+void
+atp_on_tool_edit (GtkButton *button, gpointer user_data)
 {
 	ATPToolDialog *this = (ATPToolDialog *)user_data;
 	ATPUserTool *tool;
@@ -164,8 +165,8 @@ on_tool_edit (GtkButton *button, gpointer user_data)
 	}
 }
 
-static void
-on_tool_delete (GtkButton *button, gpointer user_data)
+void
+atp_on_tool_delete (GtkButton *button, gpointer user_data)
 {
 	ATPToolDialog *this = (ATPToolDialog *)user_data;
 	ATPUserTool *tool;
@@ -181,8 +182,8 @@ on_tool_delete (GtkButton *button, gpointer user_data)
 	}	
 }
 
-static void
-on_tool_up (GtkButton *button, gpointer user_data)
+void
+atp_on_tool_up (GtkButton *button, gpointer user_data)
 {
 	ATPToolDialog *this = (ATPToolDialog *)user_data;
 	ATPUserTool *tool;
@@ -205,8 +206,8 @@ on_tool_up (GtkButton *button, gpointer user_data)
 	}
 }
 
-static void
-on_tool_down (GtkButton *button, gpointer user_data)
+void
+atp_on_tool_down (GtkButton *button, gpointer user_data)
 {
 	ATPToolDialog *this = (ATPToolDialog *)user_data;
 	ATPUserTool *tool;
@@ -224,6 +225,12 @@ on_tool_down (GtkButton *button, gpointer user_data)
 	}
 }
 
+void
+atp_on_tool_activated (GtkTreeView  *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer user_data)
+{
+	atp_on_tool_edit (NULL, user_data);
+}
+
 static void
 on_tool_enable (GtkCellRendererToggle *cell_renderer, const gchar *path, gpointer user_data)
 {
@@ -243,12 +250,6 @@ on_tool_enable (GtkCellRendererToggle *cell_renderer, const gchar *path, gpointe
 	}	
 }
 
-static void
-on_tool_activated (GtkTreeView  *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer user_data)
-{
-	on_tool_edit (NULL, user_data);
-}
-
 static void
 on_tool_selection_changed (GtkTreeSelection *selection, gpointer user_data)
 {
@@ -309,18 +310,25 @@ atp_tool_dialog_refresh (const ATPToolDialog *this, const gchar* select)
 /* Start the tool lister and editor */
 
 void
-atp_tool_dialog_show (ATPToolDialog* this, GladeXML *xml)
+atp_tool_dialog_show (ATPToolDialog* this, GtkBuilder *bxml)
 {
 	GtkTreeModel *model;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *selection;
 
-	this->dialog = GTK_WINDOW (glade_xml_get_widget(xml, TOOL_LIST));
+	/* Get widgets */
+	anjuta_util_builder_get_objects (bxml,
+	    TOOL_LIST, &this->dialog,
+	    TOOL_TREEVIEW, &this->view,
+	    TOOL_EDIT_BUTTON, &this->edit_bt, 
+	    TOOL_DELETE_BUTTON, &this->delete_bt,
+	    TOOL_UP_BUTTON, &this->up_bt,
+	    TOOL_DOWN_BUTTON, &	this->down_bt,
+	    NULL);
 	gtk_window_set_transient_for (GTK_WINDOW (this->dialog), atp_plugin_get_app_window (this->plugin));
 
 	/* Create tree view */	
-	this->view = GTK_TREE_VIEW (glade_xml_get_widget(xml, TOOL_TREEVIEW));
 	model = GTK_TREE_MODEL (gtk_list_store_new (ATP_N_TOOLS_COLUMNS,
 		G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_POINTER));
 	gtk_tree_view_set_model (this->view, model);
@@ -337,19 +345,8 @@ atp_tool_dialog_show (ATPToolDialog* this, GladeXML *xml)
 	gtk_tree_view_append_column (this->view, column);
 	g_object_unref (model);
 
-	/* Get all buttons */
-	this->edit_bt = glade_xml_get_widget(xml, TOOL_EDIT_BUTTON);
-	this->delete_bt = glade_xml_get_widget(xml, TOOL_DELETE_BUTTON);
-	this->up_bt = glade_xml_get_widget(xml, TOOL_UP_BUTTON);
-	this->down_bt = glade_xml_get_widget(xml, TOOL_DOWN_BUTTON);
-
 	/* Connect all signals */
-	glade_xml_signal_connect_data (xml, TOOL_ADD_SIGNAL, GTK_SIGNAL_FUNC (on_tool_add), this);
-	glade_xml_signal_connect_data (xml, TOOL_ACTIVATED_SIGNAL, GTK_SIGNAL_FUNC (on_tool_activated), this);
-	glade_xml_signal_connect_data (xml, TOOL_EDIT_SIGNAL, GTK_SIGNAL_FUNC (on_tool_edit), this);
-	glade_xml_signal_connect_data (xml, TOOL_DELETE_SIGNAL, GTK_SIGNAL_FUNC (on_tool_delete), this);
-	glade_xml_signal_connect_data (xml, TOOL_UP_SIGNAL, GTK_SIGNAL_FUNC (on_tool_up), this);
-	glade_xml_signal_connect_data (xml, TOOL_DOWN_SIGNAL, GTK_SIGNAL_FUNC (on_tool_down), this);
+	gtk_builder_connect_signals (bxml, this);
 	selection = gtk_tree_view_get_selection (this->view);
 	this->changed_sig = g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (on_tool_selection_changed), this);
 
